<?php
/**
 * Plugin Name:           AutomatorWP - Tutor LMS
 * Plugin URI:            https://automatorwp.com/add-ons/tutor/
 * Description:           Connect AutomatorWP with Tutor LMS.
 * Version:               1.1.3
 * Author:                AutomatorWP
 * Author URI:            https://automatorwp.com/
 * Text Domain:           automatorwp-tutor
 * Domain Path:           /languages/
 * Requires at least:     4.4
 * Tested up to:          6.3
 * License:               GNU AGPL v3.0 (http://www.gnu.org/licenses/agpl.txt)
 *
 * @package               AutomatorWP\Tutor_LMS
 * @author                AutomatorWP
 * @copyright             Copyright (c) AutomatorWP
 */

final class AutomatorWP_Tutor_LMS {

    /**
     * @var         AutomatorWP_Tutor_LMS $instance The one true AutomatorWP_Tutor_LMS
     * @since       1.0.0
     */
    private static $instance;

    /**
     * Get active instance
     *
     * @access      public
     * @since       1.0.0
     * @return      AutomatorWP_Tutor_LMS self::$instance The one true AutomatorWP_Tutor_LMS
     */
    public static function instance() {
        if( !self::$instance ) {
            self::$instance = new AutomatorWP_Tutor_LMS();
            self::$instance->constants();
            self::$instance->includes();
            self::$instance->hooks();
            self::$instance->load_textdomain();
        }

        return self::$instance;
    }

    /**
     * Setup plugin constants
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function constants() {
        // Plugin version
        define( 'AUTOMATORWP_TUTOR_VER', '1.1.3' );

        // Plugin file
        define( 'AUTOMATORWP_TUTOR_FILE', __FILE__ );

        // Plugin path
        define( 'AUTOMATORWP_TUTOR_DIR', plugin_dir_path( __FILE__ ) );

        // Plugin URL
        define( 'AUTOMATORWP_TUTOR_URL', plugin_dir_url( __FILE__ ) );
    }

    /**
     * Include plugin files
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function includes() {

        if( $this->meets_requirements() ) {

            // Triggers
            require_once AUTOMATORWP_TUTOR_DIR . 'includes/triggers/complete-quiz.php';
            require_once AUTOMATORWP_TUTOR_DIR . 'includes/triggers/complete-quiz-percentage.php';
            require_once AUTOMATORWP_TUTOR_DIR . 'includes/triggers/complete-lesson.php';
            require_once AUTOMATORWP_TUTOR_DIR . 'includes/triggers/enroll-course.php';
            require_once AUTOMATORWP_TUTOR_DIR . 'includes/triggers/complete-course.php';
            require_once AUTOMATORWP_TUTOR_DIR . 'includes/triggers/complete-quiz-category.php';
            require_once AUTOMATORWP_TUTOR_DIR . 'includes/triggers/complete-quiz-percentage-category.php';
            require_once AUTOMATORWP_TUTOR_DIR . 'includes/triggers/complete-lesson-category.php';
            require_once AUTOMATORWP_TUTOR_DIR . 'includes/triggers/enroll-course-category.php';
            require_once AUTOMATORWP_TUTOR_DIR . 'includes/triggers/complete-course-category.php';
            

            // Actions
            require_once AUTOMATORWP_TUTOR_DIR . 'includes/actions/user-course.php';
            require_once AUTOMATORWP_TUTOR_DIR . 'includes/actions/mark-lesson.php';
            require_once AUTOMATORWP_TUTOR_DIR . 'includes/actions/mark-course.php';
            require_once AUTOMATORWP_TUTOR_DIR . 'includes/actions/reset-course-progress.php';

            // Filters
            require_once AUTOMATORWP_TUTOR_DIR . 'includes/filters/user-is-enrolled-course.php';
            require_once AUTOMATORWP_TUTOR_DIR . 'includes/filters/user-is-not-enrolled-course.php';

        }
    }

    /**
     * Setup plugin hooks
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function hooks() {

        add_action( 'automatorwp_init', array( $this, 'register_integration' ) );

        add_filter( 'automatorwp_licenses_meta_boxes', array( $this, 'license' ) );

        // Setup our activation and deactivation hooks
        register_activation_hook( __FILE__, array( $this, 'activate' ) );
        register_deactivation_hook( __FILE__, array( $this, 'deactivate' ) );

        add_action( 'admin_notices', array( $this, 'admin_notices' ) );
    }

    /**
     * Registers this integration
     *
     * @since 1.0.0
     */
    function register_integration() {

        automatorwp_register_integration( 'tutor', array(
            'label' => 'Tutor LMS',
            'icon'  => AUTOMATORWP_TUTOR_URL . 'assets/tutor.svg',
        ) );

    }

    /**
     * Licensing
     *
     * @since 1.0.0
     *
     * @param array $meta_boxes
     *
     * @return array
     */
    function license( $meta_boxes ) {

        $meta_boxes['automatorwp-tutor-license'] = array(
            'title' => 'Tutor LMS',
            'fields' => array(
                'automatorwp_tutor_license' => array(
                    'type' => 'edd_license',
                    'file' => AUTOMATORWP_TUTOR_FILE,
                    'item_name' => 'Tutor LMS',
                ),
            )
        );

        return $meta_boxes;

    }

    /**
     * Activation hook for the plugin.
     *
     * @since  1.0.0
     */
    function activate() {

        if( $this->meets_requirements() ) {

        }

    }

    /**
     * Deactivation hook for the plugin.
     *
     * @since  1.0.0
     */
    function deactivate() {

    }

    /**
     * Plugin admin notices.
     *
     * @since  1.0.0
     */
    public function admin_notices() {

        if ( ! $this->meets_requirements() && ! defined( 'AUTOMATORWP_ADMIN_NOTICES' ) ) : ?>

            <div id="message" class="notice notice-error is-dismissible">
                <p>
                    <?php printf(
                        __( 'AutomatorWP - Tutor LMS requires %s and %s in order to work. Please install and activate them.', 'automatorwp-tutor' ),
                        '<a href="https://wordpress.org/plugins/automatorwp/" target="_blank">AutomatorWP</a>',
                        '<a href="https://wordpress.org/plugins/tutor/" target="_blank">Tutor LMS</a>'
                    ); ?>
                </p>
            </div>

            <?php define( 'AUTOMATORWP_ADMIN_NOTICES', true ); ?>

        <?php endif;

    }

    /**
     * Check if there are all plugin requirements
     *
     * @since  1.0.0
     *
     * @return bool True if installation meets all requirements
     */
    private function meets_requirements() {

        if ( ! class_exists( 'AutomatorWP' ) ) {
            return false;
        }

        if ( ! function_exists( 'tutor' ) ) {
            return false;
        }

        return true;

    }

    /**
     * Internationalization
     *
     * @access      public
     * @since       1.0.0
     * @return      void
     */
    public function load_textdomain() {

        // Set filter for language directory
        $lang_dir = AUTOMATORWP_TUTOR_DIR . '/languages/';
        $lang_dir = apply_filters( 'automatorwp_tutor_languages_directory', $lang_dir );

        // Traditional WordPress plugin locale filter
        $locale = apply_filters( 'plugin_locale', get_locale(), 'automatorwp-tutor' );
        $mofile = sprintf( '%1$s-%2$s.mo', 'automatorwp-tutor', $locale );

        // Setup paths to current locale file
        $mofile_local   = $lang_dir . $mofile;
        $mofile_global  = WP_LANG_DIR . '/automatorwp-tutor/' . $mofile;

        if( file_exists( $mofile_global ) ) {
            // Look in global /wp-content/languages/automatorwp-tutor/ folder
            load_textdomain( 'automatorwp-tutor', $mofile_global );
        } elseif( file_exists( $mofile_local ) ) {
            // Look in local /wp-content/plugins/automatorwp-tutor/languages/ folder
            load_textdomain( 'automatorwp-tutor', $mofile_local );
        } else {
            // Load the default language files
            load_plugin_textdomain( 'automatorwp-tutor', false, $lang_dir );
        }

    }

}

/**
 * The main function responsible for returning the one true AutomatorWP_Tutor_LMS instance to functions everywhere
 *
 * @since       1.0.0
 * @return      \AutomatorWP_Tutor_LMS The one true AutomatorWP_Tutor_LMS
 */
function AutomatorWP_Tutor_LMS() {
    return AutomatorWP_Tutor_LMS::instance();
}
add_action( 'plugins_loaded', 'AutomatorWP_Tutor_LMS' );
