<?php
/**
 * Reset Course Progress
 *
 * @package     AutomatorWP\Integrations\Tutor_LMS\Actions\Reset_Course_Progress
 * @author      AutomatorWP <contact@automatorwp.com>, Ruben Garcia <rubengcdev@gmail.com>
 * @since       1.0.0
 */
// Exit if accessed directly
if( !defined( 'ABSPATH' ) ) exit;

class AutomatorWP_Tutor_LMS_Reset_Course_Progress extends AutomatorWP_Integration_Action {

    public $integration = 'tutor';
    public $action = 'tutor_reset_course_progress';

    /**
     * Register the trigger
     *
     * @since 1.0.0
     */
    public function register() {

        automatorwp_register_action( $this->action, array(
            'integration'       => $this->integration,
            'label'             => __( 'Reset the user\'s progress in a course', 'automatorwp-tutor' ),
            'select_option'     => __( 'Reset the user\'s progress in a <strong>course</strong>', 'automatorwp-tutor' ),
            /* translators: %1$s: Post title. %2$s: Operation (completed or not completed). */
            'edit_label'        => sprintf( __( 'Reset the user\'s progress in %1$s', 'automatorwp-tutor' ), '{post}' ),
            /* translators: %1$s: Post title. %2$s: Operation (completed or not completed). */
            'log_label'         => sprintf( __( 'Reset the user\'s progress in %1$s', 'automatorwp-tutor' ), '{post}' ),
            'options'           => array(
                'post' => automatorwp_utilities_post_option( array(
                    'name'              => __( 'Course:', 'automatorwp-tutor' ),
                    'option_default'    => __( 'a course', 'automatorwp-tutor' ),
                    'placeholder'       => __( 'Select a course', 'automatorwp-tutor' ),
                    'option_none'       => false,
                    'option_custom'         => true,
                    'option_custom_desc'    => __( 'Course ID', 'automatorwp-tutor' ),
                    'post_type'         => apply_filters( 'tutor_course_post_type', 'courses' ),
                ) ),
            ),
        ) );

    }

    /**
     * Action execution function
     *
     * @since 1.0.0
     *
     * @param stdClass  $action             The action object
     * @param int       $user_id            The user ID
     * @param array     $action_options     The action's stored options (with tags already passed)
     * @param stdClass  $automation         The action's automation object
     */
    public function execute( $action, $user_id, $action_options, $automation ) {

        global $wpdb;

        // Shorthand
        $course_id = absint( $action_options['post'] );

        // Bail if not course provided
        if( $course_id === 0 ) {
            return;
        }

        // Delete all course lessons completions
        $lessons_ids = $wpdb->get_col("SELECT post_id FROM {$wpdb->postmeta} WHERE meta_key = '_tutor_course_id_for_lesson' AND meta_value = {$course_id} ");

        if ( is_array( $lessons_ids ) && count( $lessons_ids ) ) {

            $completed_lessons_metas = array();

            foreach ( $lessons_ids as $lesson_id ) {
                $completed_lessons_metas[] = '_tutor_completed_lesson_id_' . $lesson_id;
            }

            $meta_keys = implode( "','", $completed_lessons_metas );

            $wpdb->query( "DELETE FROM {$wpdb->usermeta}
                WHERE user_id = '{$user_id}'
                AND meta_key IN ('{$meta_keys}')" );
        }


        // Delete all course quizzes and assignments attempts
        $course_contents = tutils()->get_course_contents_by_id($course_id);

        if ( tutils()->count( $course_contents ) ) {
            foreach ( $course_contents as $content ) {

                switch ( $content->post_type ) {
                    case 'tutor_quiz':
                        $wpdb->query( "DELETE FROM {$wpdb->tutor_quiz_attempts}
                            WHERE quiz_id = {$content->ID}
                            AND user_id = {$user_id}" );
                        break;
                    case 'tutor_assignments':
                        $wpdb->query( "DELETE FROM {$wpdb->comments}
                            WHERE comment_type = 'tutor_assignment'
                            AND comment_post_ID = {$content->ID}
                            AND user_id = {$user_id}" );
                        break;
                }

            }
        }

        // Delete course completion flag
        $wpdb->query(" DELETE FROM {$wpdb->comments}
            WHERE comment_agent = 'TutorLMSPlugin'
            AND comment_type = 'course_completed'
            AND comment_post_ID = {$course_id}
            AND user_id = {$user_id}");

    }

}

new AutomatorWP_Tutor_LMS_Reset_Course_Progress();