<?php
/**
 * Enroll Course Category
 *
 * @package     AutomatorWP\Integrations\Tutor_LMS\Triggers\Enroll_Course_Category
 * @author      AutomatorWP <contact@automatorwp.com>, Ruben Garcia <rubengcdev@gmail.com>
 * @since       1.0.0
 */
// Exit if accessed directly
if( !defined( 'ABSPATH' ) ) exit;

class AutomatorWP_Tutor_LMS_Enroll_Course_Category extends AutomatorWP_Integration_Trigger {

    public $integration = 'tutor';
    public $trigger = 'tutor_enroll_course_category';

    /**
     * Register the trigger
     *
     * @since 1.0.0
     */
    public function register() {

        automatorwp_register_trigger( $this->trigger, array(
            'integration'       => $this->integration,
            'label'             => __( 'User is enrolled in a course of a category', 'automatorwp-tutor' ),
            'select_option'     => __( 'User <strong>is enrolled</strong> in a course of a category', 'automatorwp-tutor' ),
            /* translators: %1$s: Category. %2$s: Number of times. */
            'edit_label'        => sprintf( __( 'User is enrolled in a course of %1$s category %2$s time(s)', 'automatorwp-tutor' ), '{term}', '{times}' ),
            /* translators: %1$s: Category. */
            'log_label'         => sprintf( __( 'User is enrolled in a course of %1$s category', 'automatorwp-tutor' ), '{term}' ),
            'action'            => 'tutor_after_enrolled',
            'function'          => array( $this, 'listener' ),
            'priority'          => 10,
            'accepted_args'     => 1,
            'options'           => array(
                'term' => automatorwp_utilities_term_option( array(
                    'taxonomy' => 'course-category',
                )),
                'times' => automatorwp_utilities_times_option(),
            ),
            'tags' => array_merge(
                automatorwp_utilities_post_tags(),
                automatorwp_utilities_times_tag()
            )
        ) );

    }

    /**
     * Trigger listener
     *
     * @since 1.0.0
     *
     * @param int $course_id
     * @param int $user_id
     * @param bool $is_enrolled
     */
    public function listener( $course_id, $user_id, $is_enrolled ) {

        $user_id = get_current_user_id();

        $terms_ids = automatorwp_get_term_ids( $course_id, 'course-category' );

        // Bail if post isn't assigned to any category
        if( empty( $terms_ids ) ) {
            return;
        }

        automatorwp_trigger_event( array(
            'trigger'   => $this->trigger,
            'user_id'   => $user_id,
            'post_id'   => $course_id,
            'terms_ids' => $terms_ids,
        ) );

    }

    /**
     * User deserves check
     *
     * @since 1.0.0
     *
     * @param bool      $deserves_trigger   True if user deserves trigger, false otherwise
     * @param stdClass  $trigger            The trigger object
     * @param int       $user_id            The user ID
     * @param array     $event              Event information
     * @param array     $trigger_options    The trigger's stored options
     * @param stdClass  $automation         The trigger's automation object
     *
     * @return bool                          True if user deserves trigger, false otherwise
     */
    public function user_deserves_trigger( $deserves_trigger, $trigger, $user_id, $event, $trigger_options, $automation ) {

        // Don't deserve if post is not received
        if( ! isset( $event['post_id'] ) && ! isset( $event['terms_ids'] ) ) {
            return false;
        }

        // Don't deserve if term doesn't match with the trigger option
        if( ! automatorwp_terms_matches( $event['terms_ids'], $trigger_options['term'] ) ) {
            return false;
        }

        return $deserves_trigger;

    }

}

new AutomatorWP_Tutor_LMS_Enroll_Course_Category();